# Copyright (C) 2010, 2011 Sebastian Thiel (byronimo@gmail.com) and contributors
#
# This module is part of async and is released under
# the New BSD License: http://www.opensource.org/licenses/bsd-license.php
"""Initialize the multi-processing package"""

# initial imports
from .task import *
from .pool import *
from .channel import *
